@@ -37,7 +37,7 @@ typedef struct
 col_sel;
 
 static void
-get_color_cb (GtkWidget * widget, col_sel * sel)
+get_color_cb (col_sel *sel/*, GtkWidget *widget*/)
 {
    GdkColor color;
 
@@ -73,7 +73,7 @@ menu_color_change_cb (col_sel *sel)
 			    (selector->cancel_button), "clicked",
 			    G_CALLBACK (gtk_widget_destroy),
 			    G_OBJECT (selector), G_CONNECT_SWAPPED);
-   g_signal_connect (G_OBJECT
+   g_signal_connect_swapped (G_OBJECT
 		     (selector->ok_button),
 		     "clicked", G_CALLBACK (get_color_cb), (gpointer) sel);
    gtk_widget_show (GTK_WIDGET (selector));
