@@ -57,7 +57,7 @@ EnableSet enableSets[] = {
 gint noEnableSets = sizeof (enableSets) / sizeof (EnableSet);
 
 static gboolean
-update_enable (GtkWidget * unused, EnableSet * enableSet)
+update_enable (EnableSet *enableSet)
 {
    gboolean status = !(enableSet->get (enableSet->box));
 
@@ -159,14 +159,14 @@ create_show_hide (void)
       gtk_box_pack_start (GTK_BOX (vbox), button, TRUE, TRUE, 0);
 
       gtk_editable_set_editable (GTK_EDITABLE (entry), FALSE);
-      g_signal_connect (button, "clicked",
+      g_signal_connect_swapped (button, "clicked",
 			G_CALLBACK (update_enable),
 			(gpointer) & (enableSets[i]));
       enableSets[i].box = GTK_DATABOX (box);
       enableSets[i].entry = GTK_ENTRY (entry);
 
-      update_enable (NULL, &enableSets[i]);
-      update_enable (NULL, &enableSets[i]);
+      update_enable (&enableSets[i]);
+      update_enable (&enableSets[i]);
 
    }
 
