@@ -1,6 +1,6 @@
 #!/bin/sh
 
-aclocalincludes="-I /usr/local/share/libtool/libltdl"; 
+#aclocalincludes="-I /usr/local/share/libtool/libltdl"; 
 aclocal $aclocalincludes;
 libtoolize -c -f --automake
 autoheader; 
