@@ -3,11 +3,11 @@ PROJECT_NAME=gtkdatabox
 rm $PROJECT_NAME*.tar.gz
 rm -r */.deps
 cd pack
-nanogen.sh
+./nanogen.sh
 cd ..
 echo $PWD
 MAJOR=0
-MINOR=6
+MINOR=7
 MICRO=`cat pack/micro`
 NANO=`cat pack/nano`
 
